blame now knows -S
- From
Junio C Hamano <junkio@cox.net>
- Date
- Apr 7, 2006, 09:28 UTC
- Message-ID
- <7v1ww9loon.fsf@assigned-by-dhcp.cox.net>
I've made a few changes to "git blame" myself:
- fix breakage caused by recent revision walker reorganization; - use built-in xdiff instead of spawning GNU diff; - implement -S <ancestry-file> like annotate does.
Depending on the density of changes, it now appears that blame is 10%-30% faster than annotate. I thought CVS emulator might be interested to give it a whirl..